| check_percent | R Documentation |
check_percentcheck_percent is used to check if parameters needed by
calculate_percent are all present.
check_percent(list_of_parameters)
list_of_parameters |
is a list of parameter passed to functions that will perform the calculation |
TRUE if goi exists, else FALSE
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.