| get_metric_fun | R Documentation |
get_metric_funget_metric_fun is used to get the metrics function
and required parameters. Additional metric may set by
assigning to 'MinSNPs_metrics' variable.
get_metric_fun(metric_name = "")
metric_name |
name of the metric, by default percent/simpson |
a list, including the function to calculate the metric based on a position ('calc'), and function to check for additional parameters the function need ('args')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.